@@ -17,9 +17,9 @@ c      implicit none
       integer jclust
       real(8):: qclust
       common /clustg/ jclust(0:7,nnn),  qclust(0:12,nnn)
-
+      integer,save:: nstrange= 0
       integer i, j
-*                                                                      *
+*      should be  j=  iclust(nnn)
 *                j = 0, nucleus                                        *
 *                  = 1, proton                                         *
 *                  = 2, neutron                                        *
@@ -85,46 +85,64 @@ c      implicit none
 *                                                                      *
 ************************************************************************
       integer kfcode
-c/////////
-c      write(0,*) 'cphitsOut:  nclst=', nclst
-c      write(0,*) '  iclust =',  iclust(1:nclst)
-c//////////
+      n = 0
       do i=1, nclst
-c//////////
-c         write(0,*) 'i=', i, ' jclust=',jclust(0:7,i)
-c///////////
          if( iclust(i) == 0 ) then
-            ! nucleus
+            ! nucleus  but sometimes  p/n comes out  or even
+            !  strange ptcl  proton =2  neutron = -1 !
             charge = jclust(5,i)
             subcode = jclust(6,i)
-            code = kgnuc
+            if( subcode == 1 ) then
+               ! should be n or p; if |charge|>1, will be detected later
+               code = knuc
+               subcode = -1
+            else 
+               code = kgnuc
+            endif
          else
             kfcode=jclust(7,i)
-c/////////////
-c            write(0,*) 'i=',i, "  kfcode =",kfcode, 
-c     *           ' iclust=', iclust(i)
-c/////////////
             call ckf2cos(kfcode, code, subcode, charge)
          endif
-c/////////
-c         write(0,*)  ' calling cmkptc'
-c////////////
-         call cmkptc(code, subcode, charge, a(i))
-         
-         a(i).fm.p(4) = 
-     *    sqrt( (qclust(7, i)/1000.d0)**2 + a(i).mass**2) 
+         if( code /= krare ) then
+            if( abs(charge) > 1 .and. code == 6) then
+            !  seems to appear for pi- proj.
+            !       chg=2. i is normally
+            !      last one. chg=3,4 is also seen.
+               if( abs( qclust(5,i)- 0.9385d0) < 1.d-3 ) then
+                          !  mass
+                        !          T.E  - mass      - K.E (MeV) 
+                  if( abs( qclust(4,i)-qclust(5,i)-qclust(7,i)/1.d3)
+     *                  < 1.d-3 ) then
+            !             charge >= 1 code =6 seems proton (since mass is p)
+            !            and energy is mass + K.E so we assign it to p
+                     charge = 1
+                     goto 333
+                  endif
+               endif
+               nstrange = nstrange + 1
+               if(nstrange < 10 .or. nstrange >= 100 ) then
+                  write(0,*) 'phits: strange ptcl'
+                  write(0,*) 'code,sub,charge=', code, subcode,
+     *                 charge
+                  write(0,*)
+     *                'i=',i, ' qclust(1~7,i)=', qclust(1:7, i)
+                  write(0,*) ' nstrange=', nstrange
+                  if( nstrange >= 100) then
+                     write(0,*) 'too many '
+                     stop
+                  endif
+               endif
+               cycle  ! neglect this ptcl
+            endif
+ 333        continue
+            call cmkptc(code, subcode, charge, a(i))
+            n = n + 1
+            a(n).fm.p(4) = 
+     *           sqrt( (qclust(7, i)/1000.d0)**2 + a(n).mass**2) 
                   ! (7,i) is  K.E in MeV
-         a(i).fm.p(1) = qclust(1, i)    ! in GeV/c
-         a(i).fm.p(2) = qclust(2, i)
-         a(i).fm.p(3) = qclust(3, i)
-c/////////////////////
-c         write(0,*) ' code ,sub,ch=', code, subcode, charge
-c         write(0,*) 'i=',i, ' qclust(1~7,i)=', qclust(1:7, i)
-c         write(0,*)
-c////////////////   
+            a(n).fm.p(1) = qclust(1, i) ! in GeV/c
+            a(n).fm.p(2) = qclust(2, i)
+            a(n).fm.p(3) = qclust(3, i)
+         endif
       enddo
-      n = nclst
-c/////////
-c      write(0,*) ' exiting cjqmdout'
-c//////
       end
