@@ -26,7 +26,7 @@ c           ******************** next Absoft  fortran ***************
 c           the same one as sun/hp may be usable instead of this.
 c
        subroutine cgetLoginN(userid)
-        character*8 userid
+        character*(*) userid
  	integer getlogin,  intlogin
         pointer(pu, intlogin)
  	pu=getlogin()
@@ -46,7 +46,7 @@ c
 #elif defined GENERIC
       subroutine cgetLoginN(userid)
       implicit none
-      character*8 userid
+      character*(*) userid
       character*16 user
       character*1 NULL
       integer leng, kgetenv
@@ -60,7 +60,7 @@ c       !!!!  for HP you need +U77 compiler option
 c
        subroutine cgetLoginN(userid)
 c
-       character*8  userid
+       character*(*)  userid
        call getlog(userid)
        end
 #endif
@@ -92,8 +92,21 @@ c
       envresult=envresult(1:leng)//" "
       kgetenv2 = leng
       end
+      subroutine cqversion(cosv)
+      implicit none
+#include "Zmanagerp.h"
+      character*8::cosv ! output  cosmos version such 7.58; left justified
+      character*64::COSMOSTOP
+      character*128:: filen
+      integer kgetenv2, icon
 
-
-
-      
-
+      if( kgetenv2("COSMOSTOP", COSMOSTOP) == 0 ) then
+         write(0,*) " Environmental variable "
+         write(0,*) "COSMOSTOP cannot be obtained in cqversion"
+         stop
+      endif
+      filen = trim(COSMOSTOP)//"/Version/version" 
+      call copenf(TempDev, filen, icon)
+      read(TempDev, '(a)') cosv
+      close(TempDev)
+      end
