@@ -16,7 +16,10 @@
 
       integer::ntp2
       logical ok
-      integer inela, loop
+      integer inela, loop1, loop2
+
+      integer,parameter::maxloop=10
+ 
       record /ptcl/ tg  !
       record /ptcl/ tgspec(209), pjspec(209)
       integer:: ntgspec, npjspec, nout
@@ -36,13 +39,18 @@ c//////////
          write(0,*) 'in cjamEvent: strange target A,Z',ia,iz
          stop
       endif
+!        if 0 K.E, only elastic events are obtained-->loop
+      if(  pj.code== knuc .and. pj.charge==-1
+     *     .and.  pj.fm.p(4) - pj.mass <=0.0 ) then
+         pj.fm.p(4) = 0.001d0 + pj.mass
+c         write(0,*) ' stopping pbar '
+!           force to p target; otherwise infinite loop.
+         call cmkptc(knuc, -1, 1, tg)
+      endif
       tg.fm.p(4) = tg.mass
       tg.fm.p(1:3)= 0.
-!        if 0 K.E, only elastic events are obtained-->loop
-      if(  pj.fm.p(4) - pj.mass <=0. ) then
-         pj.fm.p(4) = 0.001 + pj.mass
-      endif
-
+      loop1 = 0
+      loop2 = 0
       ok = .false.
       do while (.not. ok)
          call cjamini(pj, tg, sig)
@@ -98,6 +106,20 @@ c///////////////
             write(0,*) ' JamXs=',JamXs, ' not usable in cjam.f'
             stop
          endif
+         if(.not. ok ) then
+            loop1 = loop1 + 1
+            if(loop1 > maxloop) then
+               write(0,*)
+     *           'In jam event gen. JamXs=',JamXs, ' inela=',inela
+               write(0,*) 'pj=',pj.code, pj.subcode,pj.charge
+               write(0,*) 'pj KE=',pj.fm.p(4)- pj.mass
+               write(0,*) 'tg A,Z=', ia,iz
+               write(0,*)' generate # of ptcls =',ntp2
+               write(0,*) 'event is neglected'
+               ntp = 0
+               exit
+            endif
+         endif
 !         # of npjesec may become 1 for pion/koan
 !           for elastic event.  (JamXs=1-->ok= f
 !                                JamXs=0-->ok= t. but 
@@ -160,6 +182,13 @@ c/////////
 c//////////////
             ntp2 = ntp2 + nout
             call cjamEconsv(pj, tg, a, ntp2, ntp, ok)
+            if(.not. ok ) then
+               loop2 = loop2 + 1
+               if(loop2 > maxloop) then
+                  exit 
+                 ! use current event with 10 % E error
+               endif
+            endif
          endif
       enddo
       call cjamElaInfo(0, inela)  ! inform inela
