@@ -55,8 +55,8 @@ c                                           for tau neutrio,  code =krare
             subcode = antip
          endif
          chg =sign(1, kf)
-      elseif(kfabs .ge. 10000) then
-         code = krare   ! target spectator. neglect
+ccc      elseif(kfabs .ge. 10000) then
+ccc         code = krare   ! target spectator. neglect
 c         p(i,5) has mass. kfabs-10000=Z
 c  &&&&&&&&&&&&&&&&&&
 c         write(msg, *) 'kf code=',kf, ' not treatable'
