@@ -24,35 +24,61 @@
 
 
         real(8):: totxs,  elaxs
-
+        integer::icon 
 
 
 
 	code = pj.code
 	subcode  = pj.subcode
 	charge = pj.charge
+
 	call ccos2phits(code, subcode, charge, ityp, ktyp)
+
         if( code == knuc  ) then
            if( subcode /= antip ) then
               call rndc(u)
-              call cphitsXs(pj, ia, iz, elaxs, totxs)
-              if(u < elaxs/totxs ) then
+              call cphitsXs(pj, ia, iz, elaxs, totxs,icon)
+              if(icon == -1) then
+                 ntp = 0
+              else 
+                 if(u < elaxs/totxs ) then
                      ! elastic
-                 call cnelas(pj, ia, iz, a, ntp)
-              else
-                 call cbertini(pj, ia, iz, sig, a, ntp)
+                    call cnelas(pj, ia, iz, a, ntp)
+                 else
+                    call cbertini(pj, ia, iz, sig, a, ntp)
+                 endif
               endif
            else
               call cjqmd(pj, ia, iz, sig, a, ntp)
+c////////////////
+c           if( pj.code == 6 .and. pj.subcode == antip .and.
+c     *        pj.charge == -1 .and. pj.fm.p(4) - pj.mass <= 0.)
+c     *         then
+c              write(0,*) '1  sig=',sig, ' ntp=',ntp
+c              do i = 1, ntp
+c                 write(0,*)  a(i).code, a(i).fm.p(4)
+c              enddo
+c           endif
+c//////////////
            endif
         elseif( code == kpion ) then
            call cbertini(pj, ia, iz, sig, a, ntp)
         else
            call cjqmd(pj, ia, iz, sig, a, ntp)
+c////////////////
+c           if( pj.code == 6 .and. pj.subcode == antip .and.
+c     *        pj.charge == -1 .and. pj.fm.p(4) - pj.mass <= 0.)
+c     *         then
+c              write(0,*) '2 sig=',sig, ' ntp=',ntp
+c              do i = 1, ntp
+c                 write(0,*)  a(i).code, a(i).fm.p(4)
+c              enddo
+c           endif
+c//////////////
         endif
 
         end subroutine
-      subroutine cphitsXs(pj, ia, iz, elaxs, totxs)
+      subroutine cphitsXs(pj, ia, iz, elaxs, totxs, icon)
       use jqmd
       use bertini
       implicit none
@@ -66,13 +92,14 @@
       real(8),intent(out):: totxs   ! xs in mb
                                  ! for p,n total (inela + elaxs)
                                  ! for Heavy  inela, elaxs =
+      integer,intent(out):: icon ! =0; oK =-1; N.G
 
       integer::incp
       real(8),save:: EkMeV, inelaxs
       real(8)::ap,zp,ep,at,zt,bmax
       integer,save:: first=0
 c            used to judge elastic or inela in cphits
-
+      integer,save:: nstrange=0
 
 
 
@@ -83,28 +110,46 @@ c            used to judge elastic or inela in cphits
          elseif(pj.charge == 0 .and. pj.subcode == regptcl) then
             incp = 2
          else
-            write(0,*) 'in cphits: code, subc, charge=', pj.code,
+            nstrange = nstrange + 1
+            if( nstrange < 10) then
+               write(0,*) 'in cphits: code, subc, charge=', pj.code,
      *             pj.subcode, pj.charge
-            write(0,*) ' anti-proton/neutron cannot be treated'
-            stop
+               write(0,*) ' strange; neglect  '
+            elseif( nstrange > 100 ) then
+               write(0,*) ' too many strange ptcl in cphits'
+               stop
+            endif
+            inelaxs = 0.
+            elaxs = 0.
+            icon = -1
+            return
          endif
          call sigrc(incp, EkMeV, ia, iz, totxs, inelaxs, elaxs)
-c             abvoe xs is in b. so to mb.
+c             abvoe xs is in b.
       elseif(pj.code == kgnuc ) then
          ap = pj.subcode
          zp = pj.charge
          ep = pj.fm.p(4) * 1000.d0   ! total E in MeV
          at = ia
          zt = iz
-!                use nasa cross-section.
+!                use Shen's (or nasa) cross-section. (icrhi=0 in cprephists
+!                  choose Shen's one (if it is  1-->Nasa XS)
 !                elaxs = 0 always. bmax not used
          call sighi(ap,zp,ep,at,zt,inelaxs, elaxs,bmax)
          totxs =  inelaxs + elaxs
       else
-         write(0,*) 'in cphits: code, subc, charge=', pj.code,
+         nstrange = nstrange + 1
+         if( nstrange < 10 ) then
+            write(0,*) 'in cphits: code, subc, charge=', pj.code,
      *        pj.subcode, pj.charge
-         write(0,*) '  cannot be treated'
-         stop
+            write(0,*) ' strange; neglected'
+         elseif ( nstrange > 100) then
+            write(0,*) ' too many strange ptcl in cphits'
+            stop
+         endif
+         inelaxs = 0.
+         elaxs = 0.
+         icon = -1
       endif
       totxs  = totxs*1000.
       inelaxs = inelaxs *1000.
