@@ -1,25 +1,6 @@
 c            hadronic collision parameters 
 c	(->  ---------------------------------------------
 
-        real*8  Cepic0  !2  Obsolute
-        real*8  Cekaon  !2  Obsolute
-        integer SucInt  !2  The number of successive interactions inside A is affected by this parameter.\newline
-                        !   If $0\rightarrow$ old formula (before uv3.500) is used, which give rather         
-                        !   smaller number ($<Nsuc>$ in Air = 1.7 for 30 mb pp), \newline
-                        !   if $1\rightarrow$ new one $<Nsuc>=2.2$ for 30 mb pp). \newline
-                        !   Default is 0 (from V5.00 again).
-        real*8  Ceneuc  !2 \verb| p -> n ; n-> p; p~->n~; n~->p~| prob.
-        real*8  Mudirp  !2 \verb| DD~| \# enhancement factor. D is only for prompt muon.
-     	real*8  Kpilog  !2  K$_{ch}/\pi_{ch}$=(Kpilog*log(ss+.069)+Kpicns)*exp(-8/s') where ss(GeV**2)= 
-                        !   effective s. s'(GeV**2)=s - 4.63.  See also Kpicns.
-        real*8  Kpicns  !2  See Kpilog. 0.077
-        real*8  Elund   !2   obsolete (from v6.0)
-c                  old def
-        real*8  Elund2  !2  obsolete (from v6.0)
-c              old def
-         real*8 Elund3   !2 obsolete  (from v6.0).
-	real*8  Efermi  !2  If Kinetic E $<$ Efermi, Fermi Momentum is considered for Nucleus target.\\
-
         character*64  IntModel !1 Interaction model description. Usage was changed from v6.0. 
                       !    One may list  code name and upper energy bound  for the code.\newline
                       ! E.g.  IntModel = '"dpmjet3"' ; to specify the dpmjet3 in the entire energy region
@@ -63,6 +44,26 @@ c                       !  The treatmen is one dimesional. May be used for neutr
                        !   $>$ 0 $\Rightarrow$    Pythia message will appear. LundPara(4) $>$ 0 Fritiof
                        !  message; both on ErrorOut. LundPara(5) =0 $\Rightarrow$    All kaons collisions
                        !  are treated as pi- in Fritiof, else they are treated by adhoc model as they are.
+!                 below: Obsolete
+        real*8  Cepic0  !2  Obsolete 
+        real*8  Cekaon  !2  Obsolete
+        integer SucInt  !2  The number of successive interactions inside A is affected by this parameter.\newline
+                        !   If $0\rightarrow$ old formula (before uv3.500) is used, which give rather         
+                        !   smaller number ($<Nsuc>$ in Air = 1.7 for 30 mb pp), \newline
+                        !   if $1\rightarrow$ new one $<Nsuc>=2.2$ for 30 mb pp). \newline
+                        !   Default is 0 (from V5.00 again).
+        real*8  Ceneuc  !2 \verb| p -> n ; n-> p; p~->n~; n~->p~| prob.
+        real*8  Mudirp  !2 \verb| DD~| \# enhancement factor. D is only for prompt muon.
+     	real*8  Kpilog  !2  K$_{ch}/\pi_{ch}$=(Kpilog*log(ss+.069)+Kpicns)*exp(-8/s') where ss(GeV**2)= 
+                        !   effective s. s'(GeV**2)=s - 4.63.  See also Kpicns.
+        real*8  Kpicns  !2  See Kpilog. 0.077
+        real*8  Elund   !2   obsolete (from v6.0)
+c                  old def
+        real*8  Elund2  !2  obsolete (from v6.0)
+c              old def
+         real*8 Elund3   !2 obsolete  (from v6.0).
+	 real*8  Efermi  !2  If Kinetic E $<$ Efermi, Fermi Momentum is considered for 
+                         ! Nucleus target.
 
 c	<-)     -----------------------------
 c            next are not input parameters.
@@ -75,9 +76,5 @@ c            next are not input parameters.
         common /Zevhnp/ Cepic0, Cekaon, Ceneuc, Mudirp, Kpilog, Eta2Pi0,
      *         Kpicns,  Efermi, Elund, Elund2, Elund3, SucPw, MulLow, 
      *         LundPara(10), SucInt
-        common /Zevhnc/RegMdls, InclusiveFile, IntModel 
-c                 this should be in block common. 
-c        data  Cepic0/0.3d0/, Cekaon/0.d0/, Ceneuc/0.35d0/,
-c    *         Mudirp/1.d0/, Kpilog/0.0062/, Kpicns/0.077/,
-c    *         Efermi/2.d0/
+        common /Zevhnc/RegMdls, InclusiveFile, IntModel
 
